==> haskell-json-0.9.1-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-json/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: json
version: 0.9.1
id: json-0.9.1-eef47fa1dd566fae8f37870d49cc3491
key: json_KtkRtvWlOxPI2zURB66Qty
license: BSD3
copyright: (c) 2007-2009 Galois Inc.
maintainer: Iavor S. Diatchki (iavor.diatchki@gmail.com)
synopsis: Support for serialising Haskell to and from JSON
description:
    JSON (JavaScript Object Notation) is a lightweight data-interchange
    format. It is easy for humans to read and write. It is easy for
    machines to parse and generate.  It is based on a subset of the
    JavaScript Programming Language, Standard ECMA-262 3rd Edition -
    December 1999.
    .
    This library provides a parser and pretty printer for converting
    between Haskell values and JSON.
category: Web
author: Galois Inc.
exposed: True
exposed-modules:
    Text.JSON Text.JSON.Types Text.JSON.String Text.JSON.ReadP
    Text.JSON.Generic Text.JSON.Pretty
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/json-0.9.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/json-0.9.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/json-0.9.1
hs-libraries: HSjson-0.9.1-KtkRtvWlOxPI2zURB66Qty
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    pretty-1.1.2.0-b06321e1e395640194b358a5374c465f
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
haddock-interfaces: /usr/share/doc/haskell-json/html/json.haddock
haddock-html: /usr/share/doc/haskell-json/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-json-0.9.1-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-json/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: json
version: 0.9.1
id: json-0.9.1-dbf392f6a0c16540f58dcd27de38198f
key: json_Cbo8lbc326q82NwJTky9zy
license: BSD3
copyright: (c) 2007-2009 Galois Inc.
maintainer: Iavor S. Diatchki (iavor.diatchki@gmail.com)
synopsis: Support for serialising Haskell to and from JSON
description:
    JSON (JavaScript Object Notation) is a lightweight data-interchange
    format. It is easy for humans to read and write. It is easy for
    machines to parse and generate.  It is based on a subset of the
    JavaScript Programming Language, Standard ECMA-262 3rd Edition -
    December 1999.
    .
    This library provides a parser and pretty printer for converting
    between Haskell values and JSON.
category: Web
author: Galois Inc.
exposed: True
exposed-modules:
    Text.JSON Text.JSON.Types Text.JSON.String Text.JSON.ReadP
    Text.JSON.Generic Text.JSON.Pretty
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/json-0.9.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/json-0.9.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/json-0.9.1
hs-libraries: HSjson-0.9.1-Cbo8lbc326q82NwJTky9zy
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    pretty-1.1.2.0-b06321e1e395640194b358a5374c465f
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
haddock-interfaces: /usr/share/doc/haskell-json/html/json.haddock
haddock-html: /usr/share/doc/haskell-json/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
